Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.FamilieVersandart Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.FamilieVersandart einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.FamilieVersandart) | Gemeinde_Modelle.FamilieVersandart |
__str__(self) (Definiert in Gemeinde_Modelle.FamilieVersandart) | Gemeinde_Modelle.FamilieVersandart |
keyFeldNavi (Definiert in Gemeinde_Modelle.FamilieVersandart) | Gemeinde_Modelle.FamilieVersandart | static
R_familie (Definiert in Gemeinde_Modelle.FamilieVersandart) | Gemeinde_Modelle.FamilieVersandart | static
R_versandart (Definiert in Gemeinde_Modelle.FamilieVersandart) | Gemeinde_Modelle.FamilieVersandart | static